# Lib
Before the major release we will put a few lines for ourselves on how to do the lib updates :)
1. Install twine if needed: `pip install build twine`
2. `python -m build`
3. `python -m twine upload dist/*`
